<center><img src="https://raw.githubusercontent.com/colav/colav.github.io/master/img/Logo.png"/></center>

# Kamunu  
Organizations IDs finder /  Akan - son of god Nyame

# Description
A package for searching organization identifiers in multiple search engines.

# Plugin
Take a look on for some examples in the repository
https://github.com/fedevergara/kamunu

# Installation

## Dependencies
**** The other dependecies can be installed with pip installing this package.

NOTE:

To start the script on conda please run the next steps

`
mkdir -p $HOME/data/db 
`

`
mongodb mongod --dbpath $HOME/data/db/
`

## Package
`pip install kamunu`

# Usage

Let's start the script executing
```.sh
kamunu_run -S "Name_of_an_organization" -O "name_of_organitation_source"
```

# License
BSD-3-Clause License 

# Links
http://colav.udea.edu.co/